@@ -27,7 +27,8 @@ class EmrClient(AbstractClient):
 
 
     def AddUsersForUserManager(self, request):
-        """新增用户列表（用户管理）
+        """该接口支持安装了OpenLdap组件的集群。
+        新增用户列表（用户管理）。
 
         :param request: Request instance for AddUsersForUserManager.
         :type request: :class:`tencentcloud.emr.v20190103.models.AddUsersForUserManagerRequest`
@@ -288,7 +289,8 @@ class EmrClient(AbstractClient):
 
 
     def DescribeUsersForUserManager(self, request):
-        """批量导出用户
+        """该接口支持安装了OpenLdap组件的集群。
+        批量导出用户。对于kerberos集群，如果需要kertab文件下载地址，可以将NeedKeytabInfo设置为true；注意SupportDownLoadKeyTab为true，但是DownLoadKeyTabUrl为空字符串，表示keytab文件在后台没有准备好（正在生成）。
 
         :param request: Request instance for DescribeUsersForUserManager.
         :type request: :class:`tencentcloud.emr.v20190103.models.DescribeUsersForUserManagerRequest`
